Adjustment Type {$ at.name $} Scaling Adjustment
You did not enter a valid number.
You must supply a scaling adjustment size.
Auto Scaling Group
You must supply a valid ID.
You must supply a auto scaling group ID.
Cooldown
You did not enter a valid number.
You did not enter a positive number.
Min Adjustment Step
You did not enter a valid integer.
You did not enter a positive number.
You must supply an integer.